@@ -33,7 +33,6 @@ class Variable:
     def __init__(self, name, varType="unsaved"):
         self.name = name
         self.varType = varType
-        self.value = 0
     
     def compile(self):
         return {"item":{"id":"var","data":{"name":self.name,"scope": self.varType}}, "slot":0}
@@ -113,7 +112,7 @@ class Line:
 
     def control(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -152,7 +151,7 @@ class Line:
     
     def selectObj(self, action, subaction="abc", *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -191,7 +190,7 @@ class Line:
 
     def entityAction(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -230,7 +229,7 @@ class Line:
 
     def gameAction(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -268,7 +267,10 @@ class Line:
         return Target(self)
     
     def playerAction(self, action, *items):
-        tags = actions[action.title()]['tags']
+        try:
+            tags = actions[action]['tags']
+        except:
+            tags = []
 
         formatted = []
 
@@ -305,7 +307,7 @@ class Line:
     
     def setVar(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -328,7 +330,7 @@ class Line:
         for tag in tags:
             formatted.append({"item": {
                 "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
-                "action": action, "block": "player_action"}},
+                "action": action, "block": "set_var"}},
                 "slot": index
             })
 
@@ -357,7 +359,7 @@ class Line:
     
     def ifEntity(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -380,7 +382,7 @@ class Line:
         for tag in tags:
             formatted.append({"item": {
                 "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
-                "action": action, "block": "player_action"}},
+                "action": action, "block": "if_entity"}},
                 "slot": index
             })
 
@@ -396,7 +398,7 @@ class Line:
     
     def ifGame(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -419,7 +421,7 @@ class Line:
         for tag in tags:
             formatted.append({"item": {
                 "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
-                "action": action, "block": "player_action"}},
+                "action": action, "block": "if_game"}},
                 "slot": index
             })
 
@@ -435,7 +437,7 @@ class Line:
 
     def ifPlayer(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -458,7 +460,7 @@ class Line:
         for tag in tags:
             formatted.append({"item": {
                 "id": "bl_tag", "data": {"tag": tag['name'], "option": tag['defaultOption'], 
-                "action": action, "block": "player_action"}},
+                "action": action, "block": "if_player"}},
                 "slot": index
             })
 
@@ -474,7 +476,7 @@ class Line:
 
     def ifVar(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
@@ -513,7 +515,7 @@ class Line:
     
     def repeat(self, action, *items):
         try:
-            tags = actions[action.title()]['tags']
+            tags = actions[action]['tags']
         except:
             tags = []
 
